# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from visier_api_data_in.models.tenant import Tenant
from typing import Optional, Set
from typing_extensions import Self

class PushDataResponse(BaseModel):
    """
    PushDataResponse
    """ # noqa: E501
    message: Optional[StrictStr] = Field(default=None, description="Any additional information about the data transfer.")
    sequence: Optional[StrictInt] = Field(default=None, description="The unique sequence number associated with a batch of records.")
    status: Optional[StrictStr] = Field(default=None, description="The status of the data transfer.")
    tenants: Optional[List[Tenant]] = Field(default=None, description="A list of strings representing the tenants that data was pushed to and their data transfer results.")
    transfer_session_id: Optional[StrictStr] = Field(default=None, description="The unique identifier associated with the transfer session.", alias="transferSessionId")
    __properties: ClassVar[List[str]] = ["message", "sequence", "status", "tenants", "transferSessionId"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PushDataResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tenants (list)
        _items = []
        if self.tenants:
            for _item_tenants in self.tenants:
                if _item_tenants:
                    _items.append(_item_tenants.to_dict())
            _dict['tenants'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PushDataResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "message": obj.get("message"),
            "sequence": obj.get("sequence"),
            "status": obj.get("status"),
            "tenants": [Tenant.from_dict(_item) for _item in obj["tenants"]] if obj.get("tenants") is not None else None,
            "transferSessionId": obj.get("transferSessionId")
        })
        return _obj





# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from visier_api_data_in.models.direct_data_schema_dto import DirectDataSchemaDTO

class TestDirectDataSchemaDTO(unittest.TestCase):
    """DirectDataSchemaDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DirectDataSchemaDTO:
        """Test DirectDataSchemaDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DirectDataSchemaDTO`
        """
        model = DirectDataSchemaDTO()
        if include_optional:
            return DirectDataSchemaDTO(
                var_schema = [
                    visier_api_data_in.models.direct_data_schema_field_dto.DirectDataSchemaFieldDTO(
                        data_type = '', 
                        empty_values_allowed = True, 
                        formats = [
                            ''
                            ], 
                        is_mandatory = True, 
                        name = '', )
                    ]
            )
        else:
            return DirectDataSchemaDTO(
        )
        """

    def testDirectDataSchemaDTO(self):
        """Test DirectDataSchemaDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from visier_api_data_in.models.credential_creation_api_response_dto import CredentialCreationAPIResponseDTO

class TestCredentialCreationAPIResponseDTO(unittest.TestCase):
    """CredentialCreationAPIResponseDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CredentialCreationAPIResponseDTO:
        """Test CredentialCreationAPIResponseDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `CredentialCreationAPIResponseDTO`
        """
        model = CredentialCreationAPIResponseDTO()
        if include_optional:
            return CredentialCreationAPIResponseDTO(
                missing_connection_properties = [
                    visier_api_data_in.models.subject_missing_access_dto.SubjectMissingAccessDTO(
                        attributes = [
                            ''
                            ], 
                        subject = 'Employee', )
                    ],
                object_name = '',
                symbol_name = '',
                uuid = ''
            )
        else:
            return CredentialCreationAPIResponseDTO(
        )
        """

    def testCredentialCreationAPIResponseDTO(self):
        """Test CredentialCreationAPIResponseDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from visier_api_data_in.models.extractor_credentials_apidto import ExtractorCredentialsAPIDTO

class TestExtractorCredentialsAPIDTO(unittest.TestCase):
    """ExtractorCredentialsAPIDTO unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExtractorCredentialsAPIDTO:
        """Test ExtractorCredentialsAPIDTO
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExtractorCredentialsAPIDTO`
        """
        model = ExtractorCredentialsAPIDTO()
        if include_optional:
            return ExtractorCredentialsAPIDTO(
                connector_credentials = [
                    visier_api_data_in.models.extractor_credential_apidto.ExtractorCredentialAPIDTO(
                        auth_context = '', 
                        credential_id = '', 
                        data_provider = '', 
                        display_name = '', 
                        is_inherited = True, )
                    ],
                limit = 56,
                start = 56
            )
        else:
            return ExtractorCredentialsAPIDTO(
        )
        """

    def testExtractorCredentialsAPIDTO(self):
        """Test ExtractorCredentialsAPIDTO"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from visier_api_data_in.models.start_extraction_request import StartExtractionRequest

class TestStartExtractionRequest(unittest.TestCase):
    """StartExtractionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> StartExtractionRequest:
        """Test StartExtractionRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `StartExtractionRequest`
        """
        model = StartExtractionRequest()
        if include_optional:
            return StartExtractionRequest(
                model = visier_api_data_in.models.start_extraction_model.StartExtractionModel(
                    all_tenants = True, 
                    batch_size_override = 56, 
                    connector_ids = [
                        ''
                        ], 
                    data_category_id = '', 
                    disable_artifact_generation = True, 
                    extract_to_time_override = '', 
                    force_update_existing_artifacts = True, 
                    last_extraction_time_offset_weeks = 56, 
                    months_to_extract = 56, 
                    override_last_extraction_timestamp = '', 
                    publish_data_load_artifacts = True, 
                    run_processing_job = True, 
                    sql_batch_size = 56, 
                    tenants = [
                        ''
                        ], )
            )
        else:
            return StartExtractionRequest(
        )
        """

    def testStartExtractionRequest(self):
        """Test StartExtractionRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Visier Data In APIs

    Visier APIs for sending data to Visier and running data load jobs.

    The version of the OpenAPI document: 0.99201.1475
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "visier-api-data-in"
VERSION = "0.99201.1475"
PYTHON_REQUIRES = ">=3.8"
REQUIRES = [
    "visier-api-core ~= 0.99201.1475",
]

setup(
    name=NAME,
    version=VERSION,
    description="Visier Data In APIs",
    author="OpenAPI Generator community",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Visier Data In APIs"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="Apache License, Version 2.0",
    long_description_content_type='text/markdown',
    long_description="""\
    Visier APIs for sending data to Visier and running data load jobs.
    """,  # noqa: E501
    package_data={"visier_api_data_in": ["py.typed"]},
)
